Learn R Programming

futureheatwaves (version 1.0.0)

number_of_heatwaves: Calculate number of heat waves

Description

This function takes a dataframe of heat waves, as created by gen_hw_set, and calculates the number of heat waves in the dataframe.

Usage

number_of_heatwaves(hw_datafr)

Arguments

hw_datafr
A dataframe of heat waves and their characteristics, as created by gen_hw_set

Value

  • A numeric value with the number of heat waves in a dataframe of heat waves, as generated by gen_hw_set.

Details

To calculate the number of heat waves, this function determines the number of rows in the dataframe, since gen_hw_set outputs a dataframe with one and only one row per heat wave.

Examples

Run this code
data(hw_datafr)
number_of_heatwaves(hw_datafr)

Run the code above in your browser using DataLab